@@ -68,10 +68,10 @@ class ModelManager(ConfigMixin):
     def process_item_parser(self, item_key: str, data: DataBag):
         item_parser = self._item_parsers[item_key]
 
-        if not item_parser:
+        if item_parser is None:
             return None
 
-        if isinstance(item_parser, (str, float, int, list, dict)):
+        if isinstance(item_parser, (str, bool, float, int, list, dict)):
             return item_parser
         elif isinstance(item_parser, models.ItemModel):
             data = data.copy(item_parser.model_manager)
@@ -161,15 +161,22 @@ class ModelManager(ConfigMixin):
 
         return data
 
-    def _apply_item_processors(self, item: dict) -> dict:
+    def _apply_item_processors(self, item: dict):
         for model in self._models:
             item = model.preprocess_item(item)
 
+            if not item:
+                return None
+
         item = mix.apply_processors(
             value=item,
             processors=list(self._item_processors_loader.values()),
+            return_on_none=True,
         )
 
+        if not item:
+            return None
+
         for model in self._models:
             item = model.process_item(item)
 
@@ -190,6 +197,9 @@ class ModelManager(ConfigMixin):
 
         item = self._apply_item_processors(item)
 
+        if not item:
+            return None
+
         return self._remove_protected_item_keys(item)
 
     def _init_model(self, model):
@@ -227,9 +237,11 @@ class ModelManager(ConfigMixin):
 
     def _init_processors_config(self):
         for item_processor in self._item_processors_loader.values():
+            item_processor.init_model(self._model)
             item_processor.init_config(self.config)
 
         for data_processor in self._data_processors_loader.values():
+            data_processor.init_model(self._model)
             data_processor.init_config(self.config)
 
     def _load_item_parsers_from_model(self, model):
